for что in ["элемент", "множество"]:
    for где in ["элемент", "множество"]:
        for регистр in ["важен", "не важен"]:
            for результат in ["содержит", "не содержит"]:
                print(f"{что} - {где}, регистр {регистр}, результат - {результат}")


видео = ".mp4"
картинка = ".jpg"
музыка = ".mp3"
ворд = ".docx"
текст = ".txt"
книга = ".fb2"
эксель = ".xlsx"

список_видео = ["фильм.mp4", "кино.mp4", "песня.MP3"]
список_картинок = ["котики.jpg", "море.jpg", "каникулы.mp4"]
список_музыки = ["мелодия.mp3", "трек.mp3", "обложка.JPG"]
список_документов = ["доклад.docx", "список дел.txt", "книга.fb2", "таблица.xlsx"]

варианты = [
    ["элемент-элемент, регистр важен, результат - не содержит", ".jpg", "обложка.JPG", True, False],
    ["элемент-элемент, регистр важен, результат - содержит", ".jpg", "котики.jpg", True, True],
    ["элемент-элемент, регистр не важен, результат - не содержит", ".jpg", "песня.MP3", False, False],
    ["элемент-элемент, регистр не важен, результат - содержит", ".jpg", "обложка.JPG", False, True],
    ["элемент-множество, регистр важен, результат - не содержит", ".mp3", список_видео, True, False],
    ["элемент-множество, регистр важен, результат - содержит", ".jpg", список_картинок, True, True],
    ["элемент-множество, регистр не важен, результат - не содержит", ".txt", список_видео, False, False],
    ["элемент-множество, регистр не важен, результат - содержит", ".mp3", список_видео, False, True],
    ["множество-элемент, регистр важен, результат - не содержит", [".jpg", ".mp3"], "песня.MP3", True, False],
    ["множество-элемент, регистр важен, результат - содержит", [".txt", ".mp3"], "список дел.txt", True, True],
    ["множество-элемент, регистр не важен, результат - не содержит", [".xlsx", ".fb2"], "трек.mp3", False, False],
    ["множество-элемент, регистр не важен, результат - содержит", [".jpg", ".mp3"], "песня.MP3", False, True],
    ["множество-множество, регистр важен, результат - не содержит", [".jpg", ".mp3"], список_видео, True, False],
    ["множество-множество, регистр важен, результат - содержит", [".mp4", ".jpg"], список_картинок, True, True],
    ["множество-множество, регистр не важен, результат - не содержит", [".docx", ".xlsx"], список_видео, False, False],
    ["множество-множество, регистр не важен, результат - содержит", [".mp3", ".docx"], список_видео, False, True],
]